package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Apr 6, 2026
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
ParseVideoJSON 解析任务 JSON:若已完成则 Done=true;若失败则 Err 非空。
type VideoTask struct {
Status string `json:"status"`
URL string `json:"url"`
Error *struct {
Message string `json:"message"`
Code any `json:"code"`
} `json:"error"`
}
VideoTask 与 New API 统一视频轮询、Kling 等 JSON 形态一致。
Source Files
¶
Click to show internal directories.
Click to hide internal directories.