comfyui

package
v0.10.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 15, 2026 License: MIT Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ConfigSchema added in v0.9.0

func ConfigSchema() []engine.ConfigField

ConfigSchema returns the configuration fields required by the ComfyUI engine.

Types

type Config

type Config struct {
	BaseURL           string
	ClientID          string
	HTTPClient        *http.Client
	WaitForCompletion bool
	PollInterval      time.Duration
}

Config configures the ComfyUI passthrough engine.

type Engine

type Engine struct {
	// contains filtered or unexported fields
}

Engine submits a graph to a ComfyUI server.

func New

func New(cfg Config) *Engine

New creates a ComfyUI engine instance.

func (*Engine) Capabilities

func (e *Engine) Capabilities() engine.Capability

Capabilities implements engine.Describer.

func (*Engine) Execute

func (e *Engine) Execute(ctx context.Context, graph workflow.Graph) (engine.Result, error)

Execute enqueues the graph on a ComfyUI server and returns either the prompt id or the first output URL.

Jump to