resolve

package
v0.27.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 28, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BoolOption

func BoolOption(g workflow.Graph, keys ...string) (bool, bool)

func ExtractPrompt added in v0.9.0

func ExtractPrompt(g workflow.Graph) (string, error)

ExtractPrompt extracts a text prompt from the workflow graph. It first checks CLIPTextEncode nodes (with link resolution), then falls back to common option keys: "prompt", "text", "value".

func Float64Option

func Float64Option(g workflow.Graph, keys ...string) (float64, bool)

func IntOption

func IntOption(g workflow.Graph, keys ...string) (int, bool)

func MergeJSONOption added in v0.9.0

func MergeJSONOption(g workflow.Graph, dst map[string]any, keys ...string)

MergeJSONOption searches for JSON-string inputs in the graph under the given keys and merges them into dst.

func NormalizeOpenAIImageSize

func NormalizeOpenAIImageSize(width, height int) string

func ResolveLinkString

func ResolveLinkString(g workflow.Graph, ref []any, seen map[string]bool) (string, bool, error)

func ResolveNodeString

func ResolveNodeString(g workflow.Graph, nodeID string, seen map[string]bool) (string, bool, error)

func ResolveValueString

func ResolveValueString(g workflow.Graph, value any, seen map[string]bool) (string, bool, error)

func StringOption

func StringOption(g workflow.Graph, keys ...string) (string, bool)

Types

This section is empty.

Jump to